"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var express = require("express");
var socketIOServer = require("socket.io");
var http = require("http");
var https = require("https");
var LiveReload = (function () {
    function LiveReload(settings) {
        this.settings = __assign(__assign({}, settings), { port: typeof settings.port !== 'undefined' ? settings.port : 3000, host: typeof settings.host !== 'undefined' ? settings.host : 'localhost', protocol: typeof settings.protocol !== 'undefined' ? settings.protocol :
                (settings.siteUrl || '').toLowerCase().indexOf('https://') === 0 ? 'https' : 'http' });
    }
    LiveReload.prototype.emitUpdatedPath = function (filePath, raw, body) {
        if (raw === void 0) { raw = false; }
        if (!raw) {
            var spRelUrl = this.settings.siteUrl + "/" + this.settings.spFolder.replace(/\\/g, '/');
            spRelUrl = spRelUrl.replace('://', '').replace(this.settings.siteUrl.replace('://', '').split('/')[0], '').replace(/\/\//g, '/');
            filePath = filePath.replace(path.resolve(this.settings.watchBase), spRelUrl).replace(/\\/g, '/').replace(/\/\//g, '/');
            filePath = decodeURIComponent(filePath).toLowerCase();
        }
        this.io.emit('live_reload', { filePath: filePath, body: body });
    };
    LiveReload.prototype.runServer = function () {
        var _this = this;
        var app = express();
        var staticRouter = express.Router();
        staticRouter.get('/*', function (req, res) {
            if (req.url.indexOf('/socket.io') !== -1) {
                var staticFilePath = path.join(process.cwd(), 'node_modules', '/socket.io-client/dist', req.url.split('?')[0]);
                res.sendFile(staticFilePath);
                return;
            }
            else if (req.url.indexOf('/live-reload.client.js') !== -1) {
                if (typeof _this.liveReloadClientContent === 'undefined') {
                    var liveReloadClientPath = path.join(__dirname, '/static', req.url.split('?')[0]);
                    var confString = JSON.stringify({
                        protocol: _this.settings.protocol,
                        host: _this.settings.host,
                        port: _this.settings.port
                    });
                    _this.liveReloadClientContent = String(fs.readFileSync(liveReloadClientPath))
                        .replace("\"##settings#\"", confString).replace("'##settings#'", confString);
                }
                res.setHeader('content-type', 'text/javascript');
                res.send(_this.liveReloadClientContent);
                return;
            }
            else {
                var staticRoot = path.join(__dirname, '/static');
                res.sendFile(path.join(staticRoot, req.url.split('?')[0]));
                return;
            }
        });
        app.use('/s', staticRouter);
        var server;
        if (this.settings.protocol === 'https') {
            if (typeof this.settings.ssl === 'undefined') {
                console.log('Error: No SSL settings provided!');
                return;
            }
            var options = {
                key: fs.readFileSync(this.settings.ssl.key),
                cert: fs.readFileSync(this.settings.ssl.cert)
            };
            server = https.createServer(options, app);
        }
        else {
            server = new http.Server(app);
        }
        this.io = socketIOServer(server);
        server.listen(this.settings.port, this.settings.host, function () {
            var address = _this.settings.protocol + "://" + _this.settings.host + ":" + _this.settings.port;
            console.log("Live reload server is up and running at " + address);
            if (_this.settings.protocol === 'https') {
                console.log('Make sure that:');
                console.log(" - monitoring script (" + address + "/s/live-reload.client.js) is provisioned to SharePoint.");
                console.log(" - SSL certificate is trusted in the browser.");
            }
            else {
                console.log("Make sure that monitoring script (" + address + "/s/live-reload.client.js) is provisioned to SharePoint.");
            }
        });
    };
    return LiveReload;
}());
exports.LiveReload = LiveReload;
//# sourceMappingURL=server.js.map